from  distutils.core import setup
from distutils import sysconfig
import sys, os, glob
from os.path import join
import platform

scripts = [join("src", "bin", "viper")]
if platform.system() == "Windows" or "bdist_wininst" in sys.argv:
    # In the Windows command prompt we can't execute Python scripts 
    # without the .py extension. A solution is to create a batch file
    # that runs the viper script.

    # try to determine the installation prefix
    # first set up a default prefix:
    if platform.system() == "Windows":
        prefix = sys.prefix
    else:
        # we are running bdist_wininst on a non-Windows platform
        pymajor, pyminor = sysconfig.get_python_version().split(".")
        prefix = "C:\\Python%s%s" % (pymajor, pyminor)

    # if --prefix is specified we use this instead of the default:
    for arg in sys.argv:
        if "--prefix" in arg:
            prefix = arg.split("=")[1]
            break

    # create batch file for Windows:
    f = open("viper.bat", "w")
    f.write("@python %s %%*" % join(prefix, "Scripts", "viper"))
    f.close()
    scripts.append("viper.bat")
    
setup(name='viper',
    version='0.4.2',
    description='Simple vtk based visualization software',
    author='Ola Skavhaug et al',
    author_email='skavhaug@simula.no',
    url='http://www.fenics.org/wiki/Viper',
    packages=['viper'],
    package_dir={'viper': join("src", "viper")},
    scripts=scripts,
    package_data={'viper': [join("data", "*.lut")]},
    data_files=[(join("share", "man", "man1"),
                 [join("doc", "man", "man1", "viper.1.gz")])]
    )

